@@ -4,6 +4,9 @@ knitr::opts_chunk$set(
   comment = "#>"
 )
 options(dplyr.summarise.inform = FALSE)
+httptest::.mockPaths("../tests/testthat")
+
+httptest::use_mock_api()
 
 ## ----setup--------------------------------------------------------------------
   library(ffscrapr)
@@ -82,3 +85,6 @@ age_summary <- ssb_values %>%
 
 age_summary
 
+## ----include = FALSE----------------------------------------------------------
+httptest::stop_mocking()
+
