@@ -4,8 +4,12 @@ with_mock_api({
     ssb_rosters <- ff_rosters(ssb)
     expect_tibble(ssb_rosters, min.rows = 300)
 
-    jml_conn <- sleeper_connect(league_id = 522458773317046272, season = 2020)
+    jml_conn <- sleeper_connect(league_id = "522458773317046272", season = 2020)
     jml_rosters <- ff_rosters(jml_conn)
     expect_tibble(jml_rosters, min.rows = 200)
+
+    joe_conn <- ff_connect(platform = "fleaflicker", league_id = 312861, season = 2020)
+    joe_rosters <- ff_rosters(joe_conn)
+    expect_tibble(joe_rosters, min.rows = 300)
   })
 })
