@@ -22,10 +22,23 @@ with_mock_api({
     )
 
     full_call <- ff_userleagues(conn)
-    quick_call <- sleeper_userleagues("solarpool",2020)
+    quick_call <- sleeper_userleagues("solarpool", 2020)
+
+    expect_tibble(full_call, min.rows = 1)
+    expect_tibble(quick_call, min.rows = 1)
+  })
+})
+
+with_mock_api({
+  test_that("ff_userleagues works for Fleaflicker", {
+    conn <- fleaflicker_connect(2020,
+      user_email = "syd235@gmail.com"
+    )
+
+    full_call <- ff_userleagues(conn)
+    quick_call <- fleaflicker_userleagues("syd235@gmail.com", 2020)
 
     expect_tibble(full_call, min.rows = 1)
     expect_tibble(quick_call, min.rows = 1)
-
   })
 })
